@@ -19,6 +19,10 @@ impl<T: SerBacker> Serializer<T> {
         Self { output: T::new() }
     }
 
+    pub fn reserve(&mut self, additional: usize) {
+        self.output.reserve(additional);
+    }
+
     /// Return a byte array with the first 4 bytes representing the size
     /// of the rest of the serialized message.
     pub fn get_output(&mut self) -> Result<&mut T> {
@@ -117,6 +121,8 @@ impl<'a, Container: SerBacker> ser::Serializer for &'a mut Serializer<Container>
     fn serialize_bytes(self, v: &[u8]) -> Result<()> {
         let len: u32 = v.len().try_into().map_err(|_| Error::TooLong)?;
 
+        self.reserve(4 + v.len());
+
         self.serialize_u32(len)?;
 
         self.output.extend_from_slice(v);
@@ -153,6 +159,9 @@ impl<'a, Container: SerBacker> ser::Serializer for &'a mut Serializer<Container>
     fn serialize_seq(self, len: Option<usize>) -> Result<Self::SerializeSeq> {
         if let Some(len) = len {
             let len: u32 = len.try_into().map_err(|_| Error::TooLong)?;
+
+            self.reserve(4 + len as usize);
+
             self.serialize_u32(len)?;
         }
         Ok(self)
